@@ -2,7 +2,7 @@
 #
 # dbginfo.sh - Tool to collect runtime, configuration, and trace information
 #
-# Copyright IBM Corp. 2002, 2017
+# Copyright IBM Corp. 2002, 2018
 #
 # s390-tools is free software; you can redistribute it and/or modify
 # it under the terms of the MIT license. See LICENSE for details.
@@ -20,8 +20,8 @@ readonly SCRIPTNAME="${0##*/}"
 # print version info
 print_version() {
     cat <<EOF
-${SCRIPTNAME}: Debug information script version 2.3.0-build-20191025
-Copyright IBM Corp. 2002, 2017
+${SCRIPTNAME}: Debug information script version 2.6.0-build-20190523
+Copyright IBM Corp. 2002, 2018
 EOF
 }
 
@@ -182,11 +182,14 @@ readonly OUTPUT_FILE_XML="${WORKPATH}domain_xml"
 # File that includes the docker inspect output
 readonly OUTPUT_FILE_DOCKER="${WORKPATH}docker_inspect.out"
 
+# File that includes nvme related information
+readonly OUTPUT_FILE_NVME="${WORKPATH}nvme.out"
+
 # Mount point of the debug file system
 readonly MOUNT_POINT_DEBUGFS="/sys/kernel/debug"
 
 # The amount of steps running the whole collections
-readonly COLLECTION_COUNT=11
+readonly COLLECTION_COUNT=12
 
 # The kernel version (e.g. '2' from 2.6.32 or '3' from 3.2.1)
 readonly KERNEL_VERSION=$(uname -r 2>/dev/null | cut -d'.' -f1)
@@ -471,10 +474,13 @@ VM_CMDS="q userid\
   :q privclass\
   :q cplevel\
   :q cpservice\
+  :q cpprot user\
+  :q specex\
   :q ssi\
   :q cpus\
   :q srm\
   :q vtod\
+  :q time full\
   :q timezone\
   :q loaddev\
   :q v osa\
@@ -826,6 +832,25 @@ collect_docker() {
     pr_log_stdout " "
 }
 
+########################################
+collect_nvme() {
+    local NVME
+
+    pr_syslog_stdout "11 of ${COLLECTION_COUNT}: Collecting nvme output"
+    call_run_command "nvme list" "${OUTPUT_FILE_NVME}"
+
+    for NVME in /dev/nvme[0-9]*; do
+	if [ -c $NVME ]; then
+	    call_run_command "smartctl -x $NVME" "${OUTPUT_FILE_NVME}"
+	    call_run_command "nvme fw-log $NVME" "${OUTPUT_FILE_NVME}"
+	    call_run_command "nvme smart-log $NVME" "${OUTPUT_FILE_NVME}"
+	    call_run_command "nvme error-log $NVME" "${OUTPUT_FILE_NVME}"
+	fi
+    done
+
+    pr_log_stdout " "
+}
+
 ########################################
 post_processing() {
     local file_mtime
@@ -833,7 +858,7 @@ post_processing() {
     local tmp_file
     local file_name
 
-    pr_syslog_stdout "11 of ${COLLECTION_COUNT}: Postprocessing"
+    pr_syslog_stdout "${COLLECTION_COUNT} of ${COLLECTION_COUNT}: Postprocessing"
 
     find "${WORKPATH}etc/libvirt/qemu/" -maxdepth 1 -name "*.xml" 2>/dev/null | while IFS= read -r file_name; do
 	file_mtime_epoche=$(stat --format=%Y "${file_name}")
@@ -992,25 +1017,31 @@ environment_setup()
 # create gzip-ped tar file
 create_package()
 {
+    local rc_tar
     pr_stdout "Finalizing: Creating archive with collected data"
     cd "${WORKDIR_BASE}"
 
-    if ! tar -czf "${WORKARCHIVE}" "${WORKDIR_CURRENT}"; then
-	pr_stdout " "
-	pr_stdout "${SCRIPTNAME}: Error: Collection of data failed!"
-	pr_stdout "       The creation of \"${WORKARCHIVE}\" was not successful."
-	pr_stdout "       Please check the directory \"${WORKDIR_BASE}\""
-	pr_stdout "       to provide enough free available space."
+    tar -czf "${WORKARCHIVE}" "${WORKDIR_CURRENT}"
+    rc_tar=$?
+    if [ $rc_tar -eq 0 ]; then
+        chmod 0600 "${WORKARCHIVE}"
+        pr_stdout " "
+        pr_stdout "Collected data was saved to:"
+        pr_stdout " >>  ${WORKARCHIVE}  <<"
+        pr_stdout " "
+        pr_stdout "Review the collected data before sending to your service organization. "
+        pr_stdout " "
+    elif [ $rc_tar -eq 127 ]; then
+        pr_stdout " "
+        pr_stdout "${SCRIPTNAME}: Error: tar command is not available!"
+        pr_stdout "     Please install the corresponding package!"
     else
-	chmod 0600 "${WORKARCHIVE}"
-	pr_stdout " "
-	pr_stdout "Collected data was saved to:"
-	pr_stdout " >>  ${WORKARCHIVE}  <<"
+        pr_stdout " "
+        pr_stdout "${SCRIPTNAME}: Error: Collection of data failed!"
+        pr_stdout "       The creation of \"${WORKARCHIVE}\" was not successful."
+        pr_stdout "       Please check the directory \"${WORKDIR_BASE}\""
+        pr_stdout "       to provide enough free available space."
     fi
-
-    pr_stdout " "
-    pr_stdout "Review the collected data before sending to your service organization. "
-    pr_stdout " "
 }
 
 
@@ -1118,6 +1149,8 @@ collect_domain_xml
 
 collect_docker
 
+collect_nvme
+
 post_processing
 
 create_package
