@@ -55,8 +55,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.6m',
  'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.6-WIimyo/python3.6-3.6.8/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.6-WIimyo/python3.6-3.6.8/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
@@ -541,7 +541,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 's390x-linux-gnu-gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 0,
+ 'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': '../Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/bin/mkdir -p',
@@ -646,7 +646,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.6-WIimyo/python3.6-3.6.8/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -687,10 +687,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.6-WIimyo/python3.6-3.6.8/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.6-WIimyo/python3.6-3.6.8/build-shared '
                './python ../Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'THREADOBJ': 'Python/thread.o',
@@ -716,8 +716,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared',
- 'abs_srcdir': '/build/python3.6-GGGPQA/python3.6-3.6.9/build-shared/..',
+ 'abs_builddir': '/build/python3.6-WIimyo/python3.6-3.6.8/build-shared',
+ 'abs_srcdir': '/build/python3.6-WIimyo/python3.6-3.6.8/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
